@@ -21,9 +21,10 @@ from iminuit import cost, Minuit
 import iminuit
 from numba_stats import norm, uniform # faster replacements for scipy.stats functions
 
-
 import glob
 
+import time
+
 def main( *args ):
     if len(args)<1:
         print("X... no object name given  (and no model given too)")
@@ -41,6 +42,19 @@ def main( *args ):
             return
 
 
+
+
+    c_orig = None
+    if ROOT.addressof(ROOT.gPad)!=0:
+        #print("\n\n\n\nD... 1FIT   I have a gpad active",ROOT.addressof(ROOT.gPad))
+        c_orig = ROOT.gPad.GetCanvas()
+        #print("\n\n\n\nD... 1FIT   I have a gpad active",ROOT.addressof(c_orig))
+    #else:
+        #print("\n\n\n\nD...  1FIT I have NONONO gpad active")
+
+    #time.sleep(1)
+
+
     fname = args[0]
     g_orig = ROOT.gDirectory.FindObject(f"{fname}")
 
@@ -208,6 +222,7 @@ def main( *args ):
     # x is channels, even if there is a calibration
     #
     #NOT POSSIBLE....area destorts    #  x = cala*x + calb
+
     yf = module.main( x,y,dy , polorder )
 
 
@@ -246,6 +261,7 @@ def main( *args ):
 
 
     # ///////////////////////////////////////////////////// plotting results
+
     cmain = ROOT.gROOT.GetListOfCanvases().FindObject("fitresult")
     if ROOT.addressof(cmain)==0:
         print("i... creating a new /fitresult/ canvas")
@@ -270,6 +286,7 @@ def main( *args ):
     ROOT.gPad.Modified()
     ROOT.gPad.Update()
 
+
     #x = x[:5]
     #yf= yf[:5]
     #y = y[:5]
@@ -278,6 +295,7 @@ def main( *args ):
 
 
     # --------------------- result plotted ---------------
+    magenta = 3
     if ishisto:
         #print(g_orig.GetXaxis().GetXmin()  , g_orig.GetXaxis().GetXmax() )
         cala = (g_orig.GetXaxis().GetXmax() - g_orig.GetXaxis().GetXmin() )/( g_orig.GetNbinsX() )
@@ -293,14 +311,30 @@ def main( *args ):
 
         data_dict["Efwhm"] = cala*data_dict["fwhm"]
 
+        data_dict["dEfwhm"] = cala*data_dict["dfwhm"]
+
+
         print(f"Energies:  {data_dict['E']:12.2f} +- {data_dict['dE']:8.2f}  fwhm= {data_dict['Efwhm']:4.2f}")
 
 
+        if abs(data_dict['diff_fit_int_proc'])>1:
+            print("X...  BAD DESCRIPTION - DIFF MORE THAN 1%")
+            magenta = 2
+        if  not( data_dict['noerror']):
+            print("X...  BAD DESCRIPTION - SOME ERROR OF FIT")
+            magenta = 2
+        if data_dict['area'] <= 2*data_dict['darea']:
+            print("X...  BAD DESCRIPTION - Area error too large")
+            magenta = 2
+        if data_dict['fwhm'] <= 2*data_dict['dfwhm']:
+            print("X...  BAD DESCRIPTION - Area error too large")
+            magenta = 2
+
 
         #print(x)
         #print(cala,calb)
     gf = ROOT.TGraph( len(x) , x.flatten("C"), yf.flatten("C") )
-    gf.SetLineColor(6) # 5 yellow 6 magenta
+    gf.SetLineColor(magenta) # 5 yellow 6 magenta
     gf.SetLineWidth(2)
     #gf.SetFillStyle(3004)
     #gf.SetFillColor(6)
@@ -371,6 +405,16 @@ def main( *args ):
 
 
 
+
+    if c_orig is not None:
+        #print("\n\n\n\nD... going back              ",ROOT.addressof(c_orig))
+        #print("\n\n\nD... going back to main TCanvas")
+        c_orig.cd()
+    #else:
+        #print("\n\n\nD... NONONO going back to main TCanvas")
+
+        #time.sleep(1)
+
     #-------------------------- I NEED to REGISTER all to be able to display on gPad
 
 
